@@ -1,3 +1,4 @@
+from _typeshed import Self
 from arpeggio.cleanpeg import NOT, prefix
 from pulumi.resource import ResourceOptions
 import pulumi_azure_native.resources as resources
@@ -8,6 +9,6 @@ def resource_group(stem, props, provider=None, parent_res=None, depends_on=None)
         resource_group_name=f'rg-{stem}',
         tags=props.tags,
         location=props.location,
-        opts=ResourceOptions(parent=parent_res,depends_on=depends_on)
+        opts=ResourceOptions(parent=self,depends_on=depends_on)
     )
     return rg
\ No newline at end of file
